pub struct EventBodyQtBorrowed<'m> {
pub kind: &'m str,
pub detail1: i32,
pub detail2: i32,
pub any_data: Value<'m>,
pub(crate) properties: QtProperties,
}Fields
kind: &'m strkind variant, used for specifying an event triple “object:state-changed:focused”, the “focus” part of this event is what is contained within the kind.
detail1: i32Generic detail1 value described by AT-SPI.
detail2: i32Generic detail2 value described by AT-SPI.
any_data: Value<'m>Generic any_data value described by AT-SPI.
This can be any type.
properties: QtPropertiesImplementations
Sourceimpl EventBodyQtBorrowed<'_>
impl EventBodyQtBorrowed<'_>
Sourcepub fn try_to_owned(&self) -> Result<EventBodyQtOwned, AtspiError>
pub fn try_to_owned(&self) -> Result<EventBodyQtOwned, AtspiError>
Convert partially borrowed Qt event body to an owned event body.
Errors
This will error if the following conditions are met:
- the
any_datafield contains anstd::os::fd::OwnedFdtype, and - the maximum number of open files for the process is exceeded.